@@ -162,7 +162,7 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
     # Fix for changed order of columns-28 Apr 2020
     colList=list("batsman"="batsman","bowler"="bowler","non_striker"="nonStriker","runs.batsman" ="runs",
                  "runs.extras" ="extras","runs.total"="totalRuns","byes"="byes","legbyes"="legbyes","noballs"="noballs",
-                 "wides"="wides","nonBoundary"="nonBoundary","penalty" ="penalty","wicket.fielders"="wicketFielder",
+                 "wides"="wides","runs.non_boundary"="nonBoundary","penalty" ="penalty","wicket.fielders"="wicketFielder",
                  "wicket.kind"="wicketKind","wicket.player_out" ="wicketPlayerOut",
                  "replacements.role.in"="replacementIn","replacements.role.out"="replacementOut",
                  "replacements.role.reason"="replacementReason","replacements.role.role"="replacementRole",
